This function generates spectra markers
FSA_spectra_marker_generator(FSdb, ratio2basePeak4nSpectraMarkers = 0,
aggregationLevel = NA)
a grouped or a matrix of ion marker masses corresponding to FSdb ids
number of spectra markers for each FSdb id
FSdb object from the 'msp2FSdb' module
Ratio of peaks in fragmentation spectra to the basepeak to calculate minimum qualified number of matched abundant peaks
c(NA, 0, 1, 2, 3). When `NA`, this function returns a matrix for the spectra markers. When integer numbers are used, the ion marker masses are grouped by a rounding digit equal to this number.