Learn R Programming

IDSL.FSA (version 1.2)

spectral_entropy_calculator: Spectral Entropy Calculator

Description

This module calculates spectral entropy for a fragmentation pattern using a method described by the reference paper.

Usage

spectral_entropy_calculator(FragmentList, allowedWeightedSpectralEntropy = TRUE,
noiseRemovalRatio = 0.01)

Value

spectralEntropy

spectral entropy

NumPeaks

NumPeaks

FragmentList

A matrix of two-columns after intensity normalization relative to summation of intensities AND entropy weight transformation when is selected.

Arguments

FragmentList

A matrix (m/z, int) of fragmentation pattern after intensity adjustment

allowedWeightedSpectralEntropy

c(TRUE, FALSE). Weighted entropy to transform low abundant signals prior to calculating entropy similarity score. Please see the reference for details on weight transformation.

noiseRemovalRatio

noise removal ratio ([0 - 1])relative to the basepeak to measure entropy similarity score.

References

Li, Y., Kind, T., Folz, J., Vaniya, A., Mehta, S.S. and Fiehn, O. (2021). Spectral entropy outperforms MS/MS dot product similarity for small-molecule compound identification. Nature methods, 18(12), 1524-1531, tools:::Rd_expr_doi("10.1038/s41592-021-01331-z")

Examples

Run this code
FragmentList <- cbind(seq(50, 600, length.out = 10), seq(10, 90, length.out = 10))
SE <- spectral_entropy_calculator(FragmentList)
print(SE[[1]])

Run the code above in your browser using DataLab